import requests
from requests_toolbelt import MultipartEncoder
from ZhihuTool.login import cookies


def set_watermark(status=False):
    url = 'https://www.zhihu.com/api/v4/me/settings'
    s = requests.session()
    if status is False:
        m = MultipartEncoder(fields={'type': 'watermark', 'value': 'disable'})
        headers = {
            'Connection': 'keep-alive',
            'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64)',
            'Content-Type': m.content_type,
            'x-xsrftoken': cookies.get('_xsrf')}
        res = s.put(url, headers=headers, data=m, cookies=cookies)
        if res.status_code == 204:
            return True
        else:
            return False
    elif status is True:
        m = MultipartEncoder(fields={'type': 'watermark', 'value': 'enable'})
        headers = {
            'Connection': 'keep-alive',
            'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64)',
            'Content-Type': m.content_type,
            'x-xsrftoken': cookies.get('_xsrf')}
        res = s.put(url, headers=headers, data=m, cookies=cookies)
        if res.status_code == 204:
            return True
        else:
            return False



import requests
import time
import os
import pickle
import zxing
import pyqrcode
import time


cookies = requests.cookies.RequestsCookieJar()


def login():
    load_cookies()
    status = check_login_status()
    if status is False:
        print('cookies过期 请重新登陆')
        return qr_login()
    else:
        print('成功从文件加载cookies')
        return True


def qr_login():
    headers = {
        'Connection': 'keep-alive',
        'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64)',
    }
    status = True
    s = requests.session()
    try:
        while status is True:
            result = get_qrcode()
            imgurl = result[0]
            token = result[1]
            res = s.get(imgurl, headers=headers, cookies=cookies)
            content = res.content
            f = open('image.png', 'wb')
            f.write(content)
            f.close()
            reader = zxing.BarCodeReader()
            raw = reader.decode("image.png").raw
            url = pyqrcode.create(raw)
            print(url.terminal(quiet_zone=1))
            start = time.time()
            while True:
                if time.time() - start < 120:
                    url = 'https://www.zhihu.com/api/v3/account/api/login/qrcode/{}/scan_info'.format(token)
                    res = s.get(url, headers=headers)
                    if res.status_code == 200:
                        content = res.json()
                        if 'status' in content:
                            if content['status'] == 1:
                                print('扫码成功 请确认登陆')
                                continue
                        else:
                            print('成功确认登陆')
                            cookies_dict = res.cookies.get_dict()
                            for key in cookies_dict:
                                cookies.set(key, cookies_dict[key])
                            q_c0 = content['cookie']['q_c0']
                            z_c0 = content['cookie']['z_c0']
                            cookies.set('q_c0', q_c0)
                            cookies.set('z_c0', z_c0)
                            save_cookies()
                            os.system('cls')
                            return True

                else:
                    print('二维码已经过期 重新加载二维码')
                    status = False
                    time.sleep(5)
            os.system('cls')
            qr_login()
    except Exception:
        return False


def get_qrcode():
    global cookies
    s = requests.session()
    headers = {
        'Connection': 'keep-alive',
        'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64)',
    }

    url = 'https://www.zhihu.com/signin?next=%2F'
    res = s.get(url=url, headers=headers)
    cookies_dict = res.cookies.get_dict()
    for key in cookies_dict:
        cookies.set(key, cookies_dict[key])

    url = 'https://www.zhihu.com/api/v3/oauth/captcha?lang=cn'
    res = s.get(url, headers=headers)
    cookies_dict = res.cookies.get_dict()
    for key in cookies_dict:
        cookies.set(key, cookies_dict[key])

    url = 'https://www.zhihu.com/udid'
    res = s.post(url=url, headers=headers)
    cookies_dict = res.cookies.get_dict()
    for key in cookies_dict:
        cookies.set(key, cookies_dict[key])

    url = 'https://www.zhihu.com/api/v3/account/api/login/qrcode'
    res = s.post(url, headers=headers, cookies=cookies, data="")
    token = res.json()['token']
    imgurl = 'https://www.zhihu.com/api/v3/account/api/login/qrcode/{}/image'.format(token)
    result = [imgurl, token]
    return result


def save_cookies():
    f = open('cookies', 'wb')
    pickle.dump(cookies, f)
    f.close()


def load_cookies():
    global cookies
    try:
        f = open('cookies.txt', 'rb')
        data = pickle.load(f)
        cookies = data
    except FileNotFoundError:
        print('cookie文件不存在')


def check_login_status():
    s = requests.session()
    url = 'https://www.zhihu.com/api/v4/me'
    headers = {
        'Connection': 'keep-alive',
        'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64)',
    }
    res = s.get(url, headers=headers, cookies=cookies)
    content = res.json()
    if 'error'in content:
        return False
    else:
        return True



from setuptools import setup


setup(
    name='zhihutool',
    version='1.0.5',
    packages=['ZhihuTool'],
    url='https://github.com/rcsupermanjob/ZhihuTool',
    license='GPLv3',
    author='rcsuperman',
    author_email='269680244@qq.com',
    description='An easy way to control your zhihu account ',
    long_description= 'An easy way to control your zhihu account',
    install_requires=[
        'pyQrcode==1.2.1',
        'requests==2.22.0',
        'zxing==0.9.3',
        'requests-toolbelt==0.9.1'
    ],
    keywords='zhihu',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
)


import requests
from ZhihuTool.login import cookies
import random


def upload(path):
    s = requests.session()
    headers = {
        "Host": "zhuanlan.zhihu.com",
        "Origin": "https://zhuanlan.zhihu.com",
        "Referer": "https://zhuanlan.zhihu.com/write",
        'Connection': 'keep-alive',
        'User-Agent': 'AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/74.0.3729.136 Mobile Safari/537.36',
        'x-xsrftoken': cookies.get('_xsrf'),
        'x-requested-with': 'Fetch',
    }
    files = {'picture': open(path, 'rb')}
    post_url = 'https://zhuanlan.zhihu.com/api/uploaded_images'
    res = s.post(post_url, files=files, headers=headers, cookies=cookies)
    content = res.json()
    print(content)
    result = []
    if 'src' in content:
        origin = content['src']
        hashcode = origin[8:].split('/')[-1].split('.')
        number = random.randint(1, 7)
        low = 'https://pic{}.zhimg.com/'.format(number) + hashcode[0] + '_hd.' + hashcode[1]
        hd = 'https://pic{}.zhimg.com/'.format(number) + hashcode[0] + '.' + hashcode[1]
        result.append('True')
        result.append(low)
        result.append(hd)
        return result
    else:
        result.append('False')
        return result
